# This code contains functions that enable easy fourier analysis

import numpy as np
from scipy.fftpack import fft, ifft

def get_fft(waveform,fs,sides = "single"):
    
    # Following example at:
    # https://pythonnumericalmethods.berkeley.edu/notebooks/chapter24.04-FFT-in-Python.html
    # Retrieved Feb. 17, 2022

    waveform = np.asarray(waveform)

    # Take the fft
    X = fft(waveform)
    N = len(X)
    frequencies = np.linspace(0,1,N) * fs

    X = X/(fs/2)

    return X, frequencies



# This contains code for basic metric calculations

import numpy as np

def get_oaspl(waveform,reference = 20e-6):
    
    waveform = np.asarray(waveform)

    return 20 * np.log10(np.std(waveform)/reference)



# This contains code that enables decibel math

import numpy as np

def add_decibels(dB,coherent = False):
   
    dB = np.asarray(dB)

    if coherent:
        summation = 20 * np.log10(sum(10**(dB/20)))
    else:
        summation = 10 * np.log10(sum(10**(dB/10)))

    return summation

def dB_to_pressure(dB,reference,squared = True):

    dB = np.asarray(dB)

    if squared:
        value = reference * 10**(dB/20)
    else:
        value = reference * 10**(dB/10)

    return value



from setuptools import setup, find_packages

VERSION = '0.1.1' 
DESCRIPTION = 'Lots of simple acoustics calculations, all in one place.'
LONG_DESCRIPTION = 'This is a package that I am writing during my time as a graduate student at Brigham Young University. My research is in aeroacoustics, and most of our code is written in MATLAB. Knowing that I may not always have access to MATLAB, and because I enjoy open-source software, I\'ve decided to create code in Python that performs many of the same tasks that we regularly perform for research. My dream is that this package can develop to the point where it could realistically be used to do all of the same research that we currently perform in MATLAB.'

# Setting up
setup(
       # the name must match the folder name 'verysimplemodule'
        name="acousticspy", 
        version=VERSION,
        author="Mark C. Anderson",
        author_email="anderson.mark.az@gmail.com",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(exclude=['tests']),
        install_requires=['numpy','scipy','matplotlib'], # add any additional packages that 
        # needs to be installed along with your package. Eg: 'caer'
        
        keywords=['python', 'acoustics'],
        classifiers= [
            "Development Status :: 2 - Pre-Alpha",
            "Intended Audience :: Science/Research",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows",
            "License :: OSI Approved :: MIT License",
            "Topic :: Scientific/Engineering",
            "Topic :: Scientific/Engineering :: Physics"
        ]
)
